@@ -14,7 +14,7 @@ def loggerDecorator(outputString):
         関数の開始～終了でコンソールに文字列を出力するデコレーター
         """
 
-        def  wrapper(*args):
+        def  wrapper(*args, **kwargs):
 
             """
             デコレーターのラッパー
@@ -23,7 +23,7 @@ def loggerDecorator(outputString):
             print('(' + outputString + ') ...', end = '')
             logging.info('(' + outputString + ') ...')
             try:
-                ret = func(*args)
+                ret = func(*args, **kwargs)
                 print('OK')
                 logging.info('OK')
             except Exception as e:
